
# React Hooks



import NpmLogo from '@site/static/img/npm-logo.png';

<div class="row margin-bottom--md">
  <div class="col">
    <a href="https://www.npmjs.com/package/@dynatrace-sdk/react-hooks" target="_blank" rel="noopener noreferrer"> <span class="margin-right--xs">@dynatrace-sdk/react-hooks</span> <img className="no-zoom" width="20px" src={NpmLogo} /> </a>
  </div>
  <div class="col" style={{textAlign: 'right'}}>
    <a href="https://www.npmjs.com/package/@dynatrace-sdk/react-hooks/v/1.1.0" target="_blank" rel="noopener noreferrer">v1.1.0</a>
  </div>
</div>

```bash
npm install @dynatrace-sdk/react-hooks
```


### Why should I use this package?

This package simplifies interactions with Grail, documents, and app states in React by encapsulating complex state management. It offers easy-to-use hooks that integrate seamlessly with client packages, enhancing developer productivity and usability in React applications.

### Simplified data querying from Grail

Traditionally, querying data in Dynatrace involves using the client-query package and managing complex React state. The useDqlQuery hook in this package streamlines this process. The following example showcases how to fetch data with a DQL query:

```javascript
const { data, error, isLoading } = useDqlQuery({ body: { query: 'fetch logs' } });
```

This hook is fully compatible with the parameters used in the `queryExecute` function of the `@dynatrace-sdk/client-query` package.

For instance, to limit the number of results returned:

```javascript
const { data, error, isLoading, refetch } = useDqlQuery(
    {
      body: {
        query: 'fetch logs',
        maxResultRecords: 2000,
      },
    },
    { autoFetch: false, autoFetchOnUpdate: false }
  );
```

You can delay the execution of the query until a user clicks on a button by passing additional options to the hook:

```javascript
const { data, error, isLoading, refetch } = useDqlQuery({body: {query:  'fetch logs'}, {autoFetch: false}});

function onClickQuery() {
  refetch();
}
```

You should add appropriate scopes to your app's configuration based on the query type. For more details, refer to the [Bucket and table permissions in Grail documentation](https://www.dynatrace.com/support/help/platform/grail/assign-permissions-in-grail).

### Interacting with documents and app states

Beyond DQL queries, our hooks facilitate interactions with documents and app state. They allow control over immediate or deferred query execution.

```javascript
const { data, error, isLoading } = useDocument({ id: documentId }, { autoFetch: true });
```

For creating, updating, or deleting documents or app state, an explicit execute call is necessary:

```javascript
const { data, execute, error } = useCreateDocument();

function onClickCreateDocument() {
  execute(DOCUMENT_DATA);
}
```

Depending on your interaction type, add these scopes to your app configuration:

| Function | Scope |
| ----- | ----- |
| Document read | document:documents:read |
| Document write/update | document:documents:write |
| Document delete | document:documents:delete |
| State read | state:app-states:read |
| State write | state:app-states:write |
| State delete | state:app-states:delete |
| User state read | state:user-app-states:read |
| User state write | state:user-app-states:write |
| User state delete | state:user-app-states:delete |

### Simplified Use of Davis® Analyzers

Leveraging Davis® analyzers traditionally involves complex state management and polling logic, alongside the `@dynatrace-sdk/client-davis-analyzers` package. The `useAnalyzer` hook in this package makes this process much more straightforward:

```javascript
const { data, error, isLoading } = useAnalyzer({
  analyzerName: 'dt.statistics.GenericForecastAnalyzer',
  body: {
    timeSeriesData: {
      expression: query,
    },
  },
});
```

This hook supports all the parameters available in the executeAnalyzer method from the `@dynatrace-sdk/client-davis-analyzers` package.

To defer the execution of the analyzer until a user action, like a button click, configure the hook with additional options:

```javascript
const { data, error, isLoading, refetch } = useAnalyzer({
  analyzerName: 'dt.statistics.GenericForecastAnalyzer',
  body: {
    timeSeriesData: {
      expression: query,
    },
  }, 
  {
    autoFetch: false,
    autoFetchOnUpdate: true,
  }
});

function onExecuteAnalyzer() {
  refetch();
}
```
In your app's configuration, include the necessary scope:

| Function | Scope |
| ----- | ----- |
| Use analyzer | davis:analyzers:execute |

### App functions

The useAppFunction hook is the simplest way to call app functions. As the other hooks in this package, it provides state handling for loading and error states:

```javascript
const { data, error, isLoading } = useAppFunction({ name: 'functionName', data: 'data' });
```

Sometimes you want to delay the execution of the app function until a user clicks on a button. This can be achieved by passing additional options to the hook:

```javascript
const { data, error, isLoading, refetch } = useAppFunction({ name: 'functionName', data: 'data' }, { autoFetch: false, autoFetchOnUpdate: false });

function onClick() {
  refetch();
}
```


## Hooks



### useAccessorPermissionsV2

<div class="padding-bottom--md">
<strong>useAccessorPermissionsV2(params,options?): Object</strong>

<div class="padding-left--md">

Load accessor permissions.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|AccessorPermissionsParamsV2|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useAllUsersPermissionsV2

<div class="padding-bottom--md">
<strong>useAllUsersPermissionsV2(params,options?): Object</strong>

<div class="padding-left--md">

Load all-users permissions.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|LoadAllUsersPermissionsParamsV2|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useAnalyzer

<div class="padding-bottom--md">
<strong>useAnalyzer(params,options?): Object</strong>

<div class="padding-left--md">

Execute an analyzer with the given data.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|AnalyzerParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useAppFunction

<div class="padding-bottom--md">
<strong>useAppFunction(params,options?): Object</strong>

<div class="padding-left--md">

Call specified app function by name.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|AppFunctionParams|App function params. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useAppState

<div class="padding-bottom--md">
<strong>useAppState(params,options?): Object</strong>

<div class="padding-left--md">

Gets app state



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|AppStateParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useAppStates

<div class="padding-bottom--md">
<strong>useAppStates(params,options?): Object</strong>

<div class="padding-left--md">

List app states



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|AppStatesParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useCreateDocument

<div class="padding-bottom--md">
<strong>useCreateDocument(): Object</strong>

<div class="padding-left--md">

Create a new document.



</div>







</div>





### useCreatePermissionsV2

<div class="padding-bottom--md">
<strong>useCreatePermissionsV2(): Object</strong>

<div class="padding-left--md">

Create a new permissions.



</div>







</div>





### useCreateSettings

<div class="padding-bottom--md">
<strong>useCreateSettings(): Object</strong>

<div class="padding-left--md">

Create a new setting.



</div>







</div>





### useCreateSettingsV2

<div class="padding-bottom--md">
<strong>useCreateSettingsV2(): Object</strong>

<div class="padding-left--md">

Create a new setting.



</div>







</div>





### useDeleteAccessorPermissionsV2

<div class="padding-bottom--md">
<strong>useDeleteAccessorPermissionsV2(): Object</strong>

<div class="padding-left--md">

Delete the accessor permissions



</div>







</div>





### useDeleteAllUsersPermissionsV2

<div class="padding-bottom--md">
<strong>useDeleteAllUsersPermissionsV2(): Object</strong>

<div class="padding-left--md">

Delete the all-users permissions



</div>







</div>





### useDeleteAppState

<div class="padding-bottom--md">
<strong>useDeleteAppState(): Object</strong>

<div class="padding-left--md">

Deletes app state



</div>







</div>





### useDeleteAppStates

<div class="padding-bottom--md">
<strong>useDeleteAppStates(): Object</strong>

<div class="padding-left--md">

Delete all app states



</div>







</div>





### useDeleteDocument

<div class="padding-bottom--md">
<strong>useDeleteDocument(): Object</strong>

<div class="padding-left--md">

Delete the document



</div>







</div>





### useDeleteSettings

<div class="padding-bottom--md">
<strong>useDeleteSettings(): Object</strong>

<div class="padding-left--md">

Delete the setting



</div>







</div>





### useDeleteSettingsV2

<div class="padding-bottom--md">
<strong>useDeleteSettingsV2(): Object</strong>

<div class="padding-left--md">

Delete the setting



</div>







</div>





### useDeleteUserAppState

<div class="padding-bottom--md">
<strong>useDeleteUserAppState(): Object</strong>

<div class="padding-left--md">

Delete user app state



</div>







</div>





### useDeleteUserAppStates

<div class="padding-bottom--md">
<strong>useDeleteUserAppStates(): Object</strong>

<div class="padding-left--md">

Delete all user app states



</div>







</div>





### useDocument

<div class="padding-bottom--md">
<strong>useDocument(params,options?): Object</strong>

<div class="padding-left--md">

Retrieve metadata and content for documents.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|DocumentParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useDocumentMetaData

<div class="padding-bottom--md">
<strong>useDocumentMetaData(params,options?): Object</strong>

<div class="padding-left--md">

Retrieve document metadata.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|DocumentMetaDataParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useDownloadDocument

<div class="padding-bottom--md">
<strong>useDownloadDocument(params,options?): Object</strong>

<div class="padding-left--md">

Download document content



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|DownloadDocumentParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useDqlQuery

<div class="padding-bottom--md">
<strong>useDqlQuery(params,options?): Object</strong>

<div class="padding-left--md">

Use this hook to execute a DQL query.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|QueryParams|Query and enrich options that will be executed. |
|options|HookOptions|Additional options for the react hook. |




#### Returns

| Description |
|---|
|The state of the query, including the result and functions to refetch or cancel the query.|





</div>





### useEffectivePermissions

<div class="padding-bottom--md">
<strong>useEffectivePermissions(params,options?): Object</strong>

<div class="padding-left--md">

Retrieve effective settings permissions for the calling user.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|Omit&lt;Object &#124; "abortSignal"&gt;|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useEffectivePermissionsV2

<div class="padding-bottom--md">
<strong>useEffectivePermissionsV2(params,options?): Object</strong>

<div class="padding-left--md">

Retrieve effective settings permissions for the calling user.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|Omit&lt;Object &#124; "abortSignal"&gt;|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useListDocuments

<div class="padding-bottom--md">
<strong>useListDocuments(params,options?): Object</strong>

<div class="padding-left--md">

List all documents accessible to you.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|undefined &#124; ListDocumentsParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### usePermissionsV2

<div class="padding-bottom--md">
<strong>usePermissionsV2(params,options?): Object</strong>

<div class="padding-left--md">

Load permissions.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|PermissionsParamsV2|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useSetAppState

<div class="padding-bottom--md">
<strong>useSetAppState(): Object</strong>

<div class="padding-left--md">

Updates app state



</div>







</div>





### useSetUserAppState

<div class="padding-bottom--md">
<strong>useSetUserAppState(): Object</strong>

<div class="padding-left--md">

Updates user app state



</div>







</div>





### useSettings

<div class="padding-bottom--md">
<strong>useSettings(params,options?): Object</strong>

<div class="padding-left--md">

Retrieve metadata and content for settings.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|SettingsParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useSettingsObjects

<div class="padding-bottom--md">
<strong>useSettingsObjects(params,options?): Object</strong>

<div class="padding-left--md">

Retrieve metadata and content for settings.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|SettingsObjectParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useSettingsObjectsV2

<div class="padding-bottom--md">
<strong>useSettingsObjectsV2(params,options?): Object</strong>

<div class="padding-left--md">

Retrieve metadata and content for settings.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|SettingsObjectParamsV2|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useSettingsV2

<div class="padding-bottom--md">
<strong>useSettingsV2(params,options?): Object</strong>

<div class="padding-left--md">

Retrieve metadata and content for settings.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|SettingsParamsV2|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useTransferOwnershipV2

<div class="padding-bottom--md">
<strong>useTransferOwnershipV2(): Object</strong>

<div class="padding-left--md">

Transfer ownership.



</div>







</div>





### useUpdateAccessorPermissionsV2

<div class="padding-bottom--md">
<strong>useUpdateAccessorPermissionsV2(): Object</strong>

<div class="padding-left--md">

Update accessor permissions.



</div>







</div>





### useUpdateAllUsersPermissionsV2

<div class="padding-bottom--md">
<strong>useUpdateAllUsersPermissionsV2(): Object</strong>

<div class="padding-left--md">

Update all-users permissions.



</div>







</div>





### useUpdateDocument

<div class="padding-bottom--md">
<strong>useUpdateDocument(): Object</strong>

<div class="padding-left--md">

Update metadata and content.



</div>







</div>





### useUpdateDocumentMetadata

<div class="padding-bottom--md">
<strong>useUpdateDocumentMetadata(): Object</strong>

<div class="padding-left--md">

Update document metadata



</div>







</div>





### useUpdateSettings

<div class="padding-bottom--md">
<strong>useUpdateSettings(): Object</strong>

<div class="padding-left--md">

Update metadata and content.



</div>







</div>





### useUpdateSettingsV2

<div class="padding-bottom--md">
<strong>useUpdateSettingsV2(): Object</strong>

<div class="padding-left--md">

Update metadata and content.



</div>







</div>





### useUserAppState

<div class="padding-bottom--md">
<strong>useUserAppState(params,options?): Object</strong>

<div class="padding-left--md">

Get user app state



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|UserAppStateParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>





### useUserAppStates

<div class="padding-bottom--md">
<strong>useUserAppStates(params,options?): Object</strong>

<div class="padding-left--md">

List user app states



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|params<sup>*required</sup>|UserAppStatesParams|Parameters for the client sdk call. |
|options|HookOptions|Additional options for the react hook. |








</div>



