/**
 * @license
 * Copyright 2023-2025 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// packages/util/react-hooks/src/useAnalyzer.ts
import {
  AnalyzerResultExecutionStatus,
  analyzersClient
} from "@dynatrace-sdk/client-davis-analyzers";

// packages/util/react-hooks/src/react-async-hook/react-async-hook.ts
import {
  useCallback,
  useEffect,
  useLayoutEffect,
  useRef,
  useState
} from "react";
var useIsomorphicLayoutEffect = typeof window !== "undefined" && typeof window.document !== "undefined" && typeof window.document.createElement !== "undefined" ? useLayoutEffect : useEffect;
var useGetter = (t) => {
  const ref = useRef(t);
  useIsomorphicLayoutEffect(() => {
    ref.current = t;
  });
  return useCallback(() => ref.current, [ref]);
};
var InitialAsyncState = {
  status: "not-requested",
  loading: false,
  result: void 0,
  error: void 0
};
var InitialAsyncLoadingState = {
  status: "loading",
  loading: true,
  result: void 0,
  error: void 0
};
var defaultSetLoading = (_asyncState) => InitialAsyncLoadingState;
var defaultSetResult = (result, _asyncState) => ({
  status: "success",
  loading: false,
  result,
  error: void 0
});
var defaultSetError = (error, _asyncState) => ({
  status: "error",
  loading: false,
  result: void 0,
  error
});
var noop = () => {
};
var DefaultOptions = {
  initialState: (options) => options && options.executeOnMount ? InitialAsyncLoadingState : InitialAsyncState,
  executeOnMount: true,
  executeOnUpdate: true,
  setLoading: defaultSetLoading,
  setResult: defaultSetResult,
  setError: defaultSetError,
  onSuccess: noop,
  onError: noop
};
var normalizeOptions = (options) => ({
  ...DefaultOptions,
  ...options
});
var useAsyncState = (options) => {
  const [value, setValue] = useState(() => options.initialState(options));
  const reset = useCallback(() => setValue(options.initialState(options)), [setValue, options]);
  const setLoading = useCallback(() => setValue(options.setLoading(value)), [value, setValue]);
  const setResult = useCallback(
    (result) => setValue(options.setResult(result, value)),
    [value, setValue]
  );
  const setError = useCallback(
    (error) => setValue(options.setError(error, value)),
    [value, setValue]
  );
  const merge = useCallback(
    (state) => setValue({
      ...value,
      ...state
    }),
    [value, setValue]
  );
  return {
    value,
    set: setValue,
    merge,
    reset,
    setLoading,
    setResult,
    setError
  };
};
var useIsMounted = () => {
  const ref = useRef(false);
  useEffect(() => {
    ref.current = true;
    return () => {
      ref.current = false;
    };
  }, []);
  return () => ref.current;
};
var useCurrentPromise = () => {
  const ref = useRef(null);
  return {
    set: (promise) => ref.current = promise,
    get: () => ref.current,
    is: (promise) => ref.current === promise
  };
};
var useAsyncInternal = (asyncFunction, params, options) => {
  !params && (params = []);
  const normalizedOptions = normalizeOptions(options);
  const [currentParams, setCurrentParams] = useState(null);
  const AsyncState = useAsyncState(normalizedOptions);
  const isMounted = useIsMounted();
  const CurrentPromise = useCurrentPromise();
  const shouldHandlePromise = (p) => isMounted() && CurrentPromise.is(p);
  const executeAsyncOperation = (...args) => {
    const promise = (async () => asyncFunction(...args))();
    setCurrentParams(args);
    CurrentPromise.set(promise);
    AsyncState.setLoading();
    promise.then(
      (result) => {
        if (shouldHandlePromise(promise)) {
          AsyncState.setResult(result);
        }
        normalizedOptions.onSuccess(result, {
          isCurrent: () => CurrentPromise.is(promise)
        });
      },
      (error) => {
        if (shouldHandlePromise(promise)) {
          AsyncState.setError(error);
        }
        normalizedOptions.onError(error, {
          isCurrent: () => CurrentPromise.is(promise)
        });
      }
    );
    return promise;
  };
  const getLatestExecuteAsyncOperation = useGetter(executeAsyncOperation);
  const executeAsyncOperationMemo = useCallback(
    (...args) => getLatestExecuteAsyncOperation()(...args),
    [getLatestExecuteAsyncOperation]
  );
  const isMounting = !isMounted();
  useEffect(() => {
    const execute = () => getLatestExecuteAsyncOperation()(...params);
    isMounting && normalizedOptions.executeOnMount && execute();
    !isMounting && normalizedOptions.executeOnUpdate && execute();
  }, params);
  return {
    ...AsyncState.value,
    set: AsyncState.set,
    merge: AsyncState.merge,
    reset: AsyncState.reset,
    execute: async (...args) => {
      try {
        return await executeAsyncOperationMemo(...args);
      } catch (e) {
        return Promise.resolve(void 0);
      }
    },
    currentPromise: CurrentPromise.get(),
    currentParams
  };
};
function useAsync(asyncFunction, params, options) {
  return useAsyncInternal(asyncFunction, params, options);
}
var useAsyncAbortable = (asyncFunction, params, options) => {
  const abortControllerRef = useRef();
  const asyncFunctionWrapper = async (...p) => {
    if (abortControllerRef.current) {
      abortControllerRef.current.abort();
    }
    const abortController = new AbortController();
    abortControllerRef.current = abortController;
    try {
      return await asyncFunction(abortController.signal, ...p);
    } finally {
      if (abortControllerRef.current === abortController) {
        abortControllerRef.current = void 0;
      }
    }
  };
  return {
    ...useAsync(asyncFunctionWrapper, params, options),
    cancel: () => abortControllerRef?.current?.abort()
  };
};
var useAsyncCallback = (asyncFunction, options) => {
  return useAsyncInternal(
    asyncFunction,
    // Hacky but in such case we don't need the params,
    // because async function is only executed manually
    [],
    {
      ...options,
      executeOnMount: false,
      executeOnUpdate: false
    }
  );
};

// packages/util/react-hooks/src/util/delay-util.ts
var delay = (ms, value, signal) => new Promise((resolve, reject) => {
  const listener = () => {
    clearTimeout(timer);
    reject(value);
  };
  const timer = setTimeout(() => {
    signal?.removeEventListener("abort", listener);
    resolve(value);
  }, ms);
  signal?.addEventListener("abort", listener);
});

// packages/util/react-hooks/src/useAnalyzer.ts
var useAnalyzer = (params, options = { autoFetch: true, autoFetchOnUpdate: true }) => {
  const result = useAsyncAbortable(
    (signal) => doExecute(params, signal),
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult(result);
};
var doExecute = async (params, abortSignal) => {
  const executeResult = await analyzersClient.executeAnalyzer({ ...params, abortSignal });
  if (executeResult.result.executionStatus === AnalyzerResultExecutionStatus.Completed) {
    return executeResult.result;
  }
  let pollResult = null;
  while (executeResult.requestToken && (pollResult === null || pollResult.result.executionStatus === AnalyzerResultExecutionStatus.Running)) {
    try {
      await delay(1e3, null, abortSignal);
      pollResult = await analyzersClient.pollAnalyzerExecution({
        analyzerName: params.analyzerName,
        requestToken: executeResult.requestToken,
        abortSignal
      });
    } finally {
      await abortAnalyzer(abortSignal, params.analyzerName, executeResult.requestToken);
    }
  }
  return pollResult?.result;
};
var getResult = (result) => {
  let error = result.error;
  if (result.error?.name === "AbortError")
    error = void 0;
  return {
    data: result.result,
    error: result.error,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isLoading: result.loading,
    isSuccess: !error && !result.loading && result.result,
    status: result.status,
    refetch: result.execute,
    cancel: result.cancel
  };
};
var abortAnalyzer = async function(signal, analyzerName, requestToken) {
  if (signal?.aborted) {
    await analyzersClient.cancelAnalyzerExecution({
      analyzerName,
      requestToken
    });
    return Promise.reject();
  }
};

// packages/util/react-hooks/src/useAppState.ts
import { stateClient } from "@dynatrace-sdk/client-state";
import { useCallback as useCallback2 } from "react";
function useAppState(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return stateClient.getAppState({ ...params, abortSignal: signal });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult2(result);
}
function useAppStates(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => stateClient.getAppStates({ ...params, abortSignal: signal }),
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult2(result);
}
function useUserAppState(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return stateClient.getUserAppState({ ...params, abortSignal: signal });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult2(result);
}
function useUserAppStates(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => stateClient.getUserAppStates({ ...params, abortSignal: signal }),
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult2(result);
}
function useDeleteAppState() {
  const execute = useCallback2(async (params) => {
    await result.execute(params);
  }, []);
  const result = useAsyncCallback((params) => stateClient.deleteAppState({ ...params }));
  return getCallbackResult(result, execute);
}
function useDeleteAppStates() {
  const result = useAsyncCallback(() => stateClient.deleteAppStates());
  return getCallbackResult(result, result.execute);
}
function useDeleteUserAppState() {
  const execute = useCallback2(async (params) => {
    await result.execute(params);
  }, []);
  const result = useAsyncCallback((params) => stateClient.deleteUserAppState({ ...params }));
  return getCallbackResult(result, execute);
}
function useDeleteUserAppStates() {
  const result = useAsyncCallback(() => stateClient.deleteUserAppStates());
  return getCallbackResult(result, result.execute);
}
function useSetAppState() {
  const execute = useCallback2(async (params) => {
    await result.execute(params);
  }, []);
  const result = useAsyncCallback(
    (params) => stateClient.setAppState({ ...params })
  );
  return getCallbackResult(result, execute);
}
function useSetUserAppState() {
  const execute = useCallback2(async (params) => {
    await result.execute(params);
  }, []);
  const result = useAsyncCallback(
    (params) => stateClient.setUserAppState({ ...params })
  );
  return getCallbackResult(result, execute);
}
function getCallbackResult(result, execute) {
  const error = result.error;
  return {
    execute,
    data: result.result,
    error: result.error,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isSuccess: !error && !result.loading && result.result,
    isLoading: result.loading,
    status: result.status
  };
}
function getResult2(result) {
  const error = result.error;
  return {
    data: result.result,
    error: result.error,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isLoading: result.loading,
    isSuccess: !error && !result.loading && result.result,
    status: result.status,
    refetch: result.execute,
    cancel: result.cancel
  };
}

// packages/util/react-hooks/src/useDocument.ts
import { documentsClient } from "@dynatrace-sdk/client-document";
import { useRef as useRef2 } from "react";
function useDocument(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => documentsClient.getDocument({ ...params, abortSignal: signal }),
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult3(result);
}
function useDocumentMetaData(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => documentsClient.getDocumentMetadata({
      ...params,
      abortSignal: signal
    }),
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult3(result);
}
function useListDocuments(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    async (signal) => documentsClient.listDocuments({ ...params, abortSignal: signal }),
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult3(result);
}
function useDownloadDocument(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => documentsClient.downloadDocumentContent({ ...params, abortSignal: signal }),
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult3(result);
}
function useCreateDocument() {
  const executeParams = useRef2();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return documentsClient.createDocument({ ...executeParams.current });
    }
  });
  return getCallbackResult2(result, execute);
}
function useUpdateDocument() {
  const executeParams = useRef2();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return documentsClient.updateDocument({ ...executeParams.current });
    }
  });
  return getCallbackResult2(result, execute);
}
function useUpdateDocumentMetadata() {
  const executeParams = useRef2();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return documentsClient.updateDocumentMetadata({ ...executeParams.current });
    }
  });
  return getCallbackResult2(result, execute);
}
function useDeleteDocument() {
  const executeParams = useRef2();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return documentsClient.deleteDocument({ ...executeParams.current });
    }
  });
  return getCallbackResult2(result, execute);
}
function getCallbackResult2(result, execute) {
  const error = result.error;
  return {
    execute,
    data: result.result,
    error: result.error,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isSuccess: !error && !result.loading && result.result,
    isLoading: result.loading,
    status: result.status
  };
}
function getResult3(result) {
  const error = result.error;
  return {
    data: result.result,
    error: result.error,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isLoading: result.loading,
    isSuccess: !error && !result.loading && result.result,
    status: result.status,
    refetch: result.execute,
    cancel: result.cancel
  };
}

// packages/util/react-hooks/src/useDqlQuery.ts
import {
  queryExecutionClient,
  QueryState
} from "@dynatrace-sdk/client-query";
function useDqlQuery(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => doQuery(params, signal),
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  let error = result.error;
  if (result.error?.name === "AbortError")
    error = void 0;
  return {
    data: result.result,
    error: error ? result.error : void 0,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isLoading: result.loading,
    isSuccess: !error && !result.loading && !!result.result,
    status: result.status,
    refetch: result.execute,
    cancel: result.cancel
  };
}
var doQuery = async function(params, signal) {
  const executeResult = await queryExecutionClient.queryExecute({
    ...params,
    abortSignal: signal
  });
  if (!(executeResult.state === QueryState.Running || executeResult.state === QueryState.NotStarted || executeResult.result === void 0)) {
    return executeResult.result;
  }
  let queryResult = null;
  while (executeResult.requestToken && (queryResult === null || queryResult.state === QueryState.Running || queryResult.state === QueryState.NotStarted)) {
    try {
      await delay(1e3, null, signal);
    } finally {
      await abortQuery(signal, executeResult.requestToken);
    }
    try {
      queryResult = await queryExecutionClient.queryPoll({
        requestToken: executeResult.requestToken,
        enrich: params?.enrich,
        abortSignal: signal
      });
    } finally {
      await abortQuery(signal, executeResult.requestToken);
    }
  }
  return queryResult?.result;
};
var abortQuery = async function(signal, requestToken) {
  if (signal?.aborted) {
    await queryExecutionClient.queryCancel({
      requestToken
    });
    return Promise.reject();
  }
};

// packages/util/react-hooks/src/useAppFunction.ts
import { functions } from "@dynatrace-sdk/app-utils";
function useAppFunction({ name, data, responseType = "json" }, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => functions.call(name, { data, abortSignal: signal }).then((res) => res[responseType]()),
    [JSON.stringify(data)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return {
    data: result.result,
    error: result.error,
    isError: !!result.error,
    isLoading: result.loading,
    isSuccess: !result.error && !result.loading && !!result.result,
    status: result.status,
    refetch: result.execute,
    cancel: result.cancel
  };
}

// packages/util/react-hooks/src/useSettings.ts
import {
  appSettingsObjectsClient
} from "@dynatrace-sdk/client-app-settings";
import { useRef as useRef3 } from "react";
function useSettings(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient.getEffectiveAppSettingsValues({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult4(result);
}
function useSettingsObjects(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient.getAppSettingsObjects({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult4(result);
}
function useEffectivePermissions(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient.resolveEffectivePermissions({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult4(result);
}
function useDeleteSettings() {
  const executeParams = useRef3();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient.deleteAppSettingsObjectByObjectId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult3(result, execute);
}
function useUpdateSettings() {
  const executeParams = useRef3();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient.putAppSettingsObjectByObjectId({ ...executeParams.current });
    }
  });
  return getCallbackResult3(result, execute);
}
function useCreateSettings() {
  const executeParams = useRef3();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient.postAppSettingsObject({ ...executeParams.current });
    }
  });
  return getCallbackResult3(result, execute);
}
function getCallbackResult3(result, execute) {
  const error = result.error;
  return {
    execute,
    data: result.result,
    error: error ? result.error : void 0,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isSuccess: !error && !result.loading && result.result,
    isLoading: result.loading,
    status: result.status
  };
}
function getResult4(result) {
  const error = result.error;
  return {
    data: result.result,
    error: error ? result.error : void 0,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isLoading: result.loading,
    isSuccess: !error && !result.loading && result.result,
    status: result.status,
    refetch: result.execute,
    cancel: result.cancel
  };
}

// packages/util/react-hooks/src/useSettingsV2.ts
import { appSettingsObjectsClient as appSettingsObjectsClient2 } from "@dynatrace-sdk/client-app-settings-v2";
import { useRef as useRef4 } from "react";
function useSettingsV2(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient2.getEffectiveAppSettingsValues({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult5(result);
}
function useSettingsObjectsV2(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient2.getAppSettingsObjects({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult5(result);
}
function useEffectivePermissionsV2(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient2.resolveEffectivePermissions({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult5(result);
}
function useDeleteSettingsV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.deleteAppSettingsObjectByObjectId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function useUpdateSettingsV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.putAppSettingsObjectByObjectId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function useCreateSettingsV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.postAppSettingsObject({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function useTransferOwnershipV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.postAppSettingsOwnershipByObjectId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function useAccessorPermissionsV2(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient2.getAppSettingsPermissionByObjectIdAndAccessorId({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult5(result);
}
function useUpdateAccessorPermissionsV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.putAppSettingsPermissionByObjectIdAndAccessorId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function useDeleteAccessorPermissionsV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.deleteAppSettingsPermissionByObjectIdAndAccessorId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function usePermissionsV2(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient2.getAppSettingsPermissionsByObjectId({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult5(result);
}
function useCreatePermissionsV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.postAppSettingsPermissionByObjectId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function useAllUsersPermissionsV2(params, options = { autoFetch: true, autoFetchOnUpdate: true }) {
  const result = useAsyncAbortable(
    (signal) => {
      return appSettingsObjectsClient2.getAppSettingsAllUsersPermissionByObjectId({
        ...params,
        abortSignal: signal
      });
    },
    [JSON.stringify(params)],
    { executeOnMount: options.autoFetch, executeOnUpdate: options.autoFetchOnUpdate }
  );
  return getResult5(result);
}
function useUpdateAllUsersPermissionsV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.putAppSettingsAllUsersPermissionByObjectId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function useDeleteAllUsersPermissionsV2() {
  const executeParams = useRef4();
  const execute = async (params) => {
    executeParams.current = params;
    await result.execute();
  };
  const result = useAsyncCallback(() => {
    if (executeParams.current) {
      return appSettingsObjectsClient2.deleteAppSettingsAllUsersPermissionByObjectId({
        ...executeParams.current
      });
    }
  });
  return getCallbackResult4(result, execute);
}
function getCallbackResult4(result, execute) {
  const error = result.error;
  return {
    execute,
    data: result.result,
    error: error ? result.error : void 0,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isSuccess: !error && !result.loading && result.result,
    isLoading: result.loading,
    status: result.status
  };
}
function getResult5(result) {
  const error = result.error;
  return {
    data: result.result,
    error: error ? result.error : void 0,
    errorDetails: error?.body?.error,
    isError: error ? true : false,
    isLoading: result.loading,
    isSuccess: !error && !result.loading && result.result,
    status: result.status,
    refetch: result.execute,
    cancel: result.cancel
  };
}
export {
  useAccessorPermissionsV2,
  useAllUsersPermissionsV2,
  useAnalyzer,
  useAppFunction,
  useAppState,
  useAppStates,
  useCreateDocument,
  useCreatePermissionsV2,
  useCreateSettings,
  useCreateSettingsV2,
  useDeleteAccessorPermissionsV2,
  useDeleteAllUsersPermissionsV2,
  useDeleteAppState,
  useDeleteAppStates,
  useDeleteDocument,
  useDeleteSettings,
  useDeleteSettingsV2,
  useDeleteUserAppState,
  useDeleteUserAppStates,
  useDocument,
  useDocumentMetaData,
  useDownloadDocument,
  useDqlQuery,
  useEffectivePermissions,
  useEffectivePermissionsV2,
  useListDocuments,
  usePermissionsV2,
  useSetAppState,
  useSetUserAppState,
  useSettings,
  useSettingsObjects,
  useSettingsObjectsV2,
  useSettingsV2,
  useTransferOwnershipV2,
  useUpdateAccessorPermissionsV2,
  useUpdateAllUsersPermissionsV2,
  useUpdateDocument,
  useUpdateDocumentMetadata,
  useUpdateSettings,
  useUpdateSettingsV2,
  useUserAppState,
  useUserAppStates
};
