import { AbortSignal, HttpClient } from '@dynatrace-sdk/http-client';
import { AppSettingsAccessorPermissions } from '../models/app-settings-accessor-permissions';
import { AppSettingsAccessorPermissionsList } from '../models/app-settings-accessor-permissions-list';
import { AppSettingsObject } from '../models/app-settings-object';
import { AppSettingsObjectCreate } from '../models/app-settings-object-create';
import { AppSettingsObjectResponse } from '../models/app-settings-object-response';
import { AppSettingsObjectUpdate } from '../models/app-settings-object-update';
import { AppSettingsObjectsList } from '../models/app-settings-objects-list';
import { AppSettingsTransferOwnershipRequest } from '../models/app-settings-transfer-ownership-request';
import { AppSettingsUpdatePermissionsRequest } from '../models/app-settings-update-permissions-request';
import { AppSettingsUpdateResponse } from '../models/app-settings-update-response';
import { EffectiveAppSettingsValuesList } from '../models/effective-app-settings-values-list';
import { EffectivePermissions } from '../models/effective-permissions';
import { ResolutionRequest } from '../models/resolution-request';
import { ApiClientOptions } from './api-client-options';
/**
 * Manage settings objects for apps
 */
export declare class AppSettingsObjectsClient {
    private httpClient;
    private shouldTransformDates;
    /**
     * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a AppSettingsObjectsClient. Custom http client should implement {HttpClient} interface.
     * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
     * @example
     * const appSettingsObjectsClientNodeJs = new AppSettingsObjectsClient(yourCustomImplementation);
     */
    constructor(httpClientImplementation: HttpClient, options?: ApiClientOptions);
    /**
     * Gets the specified settings object
     *
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Gets the specified settings object. Properties of type **secret** will be included in plain text if the call originates from a serverless function of your app; they will have irreversibly masked values otherwise. This protects these secrets from leaking to users of your app or other third parties.
     *
     * @returns {Promise<AppSettingsObject>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.getAppSettingsObjectByObjectId(
     *     { objectId: "..." },
     *   );
     *
     * @throws {ErrorResponseError} Failed. The input is invalid. | Failed. Forbidden. | No object available for the given objectId
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getAppSettingsObjectByObjectId(config: {
        /** The ID of the required settings object */ objectId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsObject>;
    /**
     * Updates an existing settings object
     *
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Updates an existing settings object with new values. To update a property of the `secret` type you need to pass the new value unmasked. To keep the current value, send the current masked secret. You can obtain it via [GET an object](#getappsettingsobjects) endpoint.
     *
     * Some schemas don't allow passing of the masked secret. In that case you need to send the unmasked secret with every update of the object.
     *
     * @returns {Promise<AppSettingsUpdateResponse>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.putAppSettingsObjectByObjectId(
     *     {
     *       objectId: "...",
     *       optimisticLockingVersion: "...",
     *       body: { value: {} },
     *     },
     *   );
     *
     * @throws {ErrorResponseError} Failed. The input is invalid. | Failed. Forbidden. | Failed. The requested resource doesn't exist.
     * @throws {ConflictingResource} Failed. Conflicting resource.
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    putAppSettingsObjectByObjectId(config: {
        body: AppSettingsObjectUpdate;
        /** The ID of the required settings object */ objectId: string;
        /**
         * The version of the object for optimistic locking. You can use it to detect simultaneous modifications by different users.
         *
         * It is generated upon retrieval (GET requests). If set on update (PUT request) or deletion, the update/deletion will be allowed only if there wasn't any change between the retrieval and the update.
         */ optimisticLockingVersion: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsUpdateResponse>;
    /**
     * Deletes the specified settings object
     *
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.deleteAppSettingsObjectByObjectId(
     *     { objectId: "...", optimisticLockingVersion: "..." },
     *   );
     *
     * @throws {ErrorResponseError} Failed. The input is invalid. | Failed. Forbidden. | Failed. The requested resource doesn't exist.
     * @throws {ConflictingResource} Failed. Conflicting resource.
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteAppSettingsObjectByObjectId(config: {
        /** The ID of the required settings object */ objectId: string;
        /**
         * The version of the object for optimistic locking. You can use it to detect simultaneous modifications by different users.
         *
         * It is generated upon retrieval (GET requests). If set on update (PUT request) or deletion, the update/deletion will be allowed only if there wasn't any change between the retrieval and the update.
         */ optimisticLockingVersion: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Transfer ownership of the object, only the owner or the main admin is allowed to transfer the ownership (IAM permission needed).
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.postAppSettingsOwnershipByObjectId(
     *     {
     *       objectId: "...",
     *       body: { newOwner: { type: IdentityType.User } },
     *     },
     *   );
     *
     * @throws {ErrorResponseError} No object available for the given objectId
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    postAppSettingsOwnershipByObjectId(config: {
        body: AppSettingsTransferOwnershipRequest;
        /** The ID of the required settings object */ objectId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Get current permissions on this object
     *
     * @returns {Promise<AppSettingsAccessorPermissionsList>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.getAppSettingsPermissionsByObjectId(
     *     { objectId: "..." },
     *   );
     *
     * @throws {ErrorResponseError} No object available for the given objectId
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getAppSettingsPermissionsByObjectId(config: {
        /** The ID of the required settings object */ objectId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsAccessorPermissionsList>;
    /**
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Add the permissions for a single accessor on this object, anyone with read/write permissions is allowed to add more permissions
     *
     * @returns {Promise<AppSettingsAccessorPermissions>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.postAppSettingsPermissionByObjectId(
     *     {
     *       objectId: "...",
     *       body: {
     *         accessor: { type: IdentityType.User },
     *         permissions: {},
     *       },
     *     },
     *   );
     *
     * @throws {ErrorResponseError} if accessor id already exists | No object available for the given objectId
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    postAppSettingsPermissionByObjectId(config: {
        body: AppSettingsAccessorPermissions;
        /** The ID of the required settings object */ objectId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsAccessorPermissions>;
    /**
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Get current permissions of the accessor on this object
     *
     * @returns {Promise<AppSettingsAccessorPermissions>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.getAppSettingsPermissionByObjectIdAndAccessorId(
     *     {
     *       objectId: "...",
     *       accessorType:
     *         GetAppSettingsPermissionByObjectIdAndAccessorIdPathAccessorType.User,
     *       accessorId: "...",
     *     },
     *   );
     *
     * @throws {ErrorResponseError} No object available for the given objectId or the accessor doesn't have any permissions on this object
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getAppSettingsPermissionByObjectIdAndAccessorId(config: {
        /** The ID of the required settings object */ objectId: string;
        /** The type of the accessor */ accessorType: 'user' | 'group';
        /** The user uuid or group uuid of the accessor, depending on the type */ accessorId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsAccessorPermissions>;
    /**
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Update the permissions for an existing accessor on this object, anyone with read/write permissions is allowed to update permissions
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.putAppSettingsPermissionByObjectIdAndAccessorId(
     *     {
     *       objectId: "...",
     *       accessorType:
     *         GetAppSettingsPermissionByObjectIdAndAccessorIdPathAccessorType.User,
     *       accessorId: "...",
     *       body: { permissions: {} },
     *     },
     *   );
     *
     * @throws {ErrorResponseError} if permission list is empty, contains unsupported entries or unsupported combinations of entries | No object available for the given objectId or the accessor doesn't have any permissions on this object
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    putAppSettingsPermissionByObjectIdAndAccessorId(config: {
        body: AppSettingsUpdatePermissionsRequest;
        /** The ID of the required settings object */ objectId: string;
        /** The type of the accessor */ accessorType: 'user' | 'group';
        /** The user uuid or group uuid of the accessor, depending on the type */ accessorId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Remove the permissions for an existing accessor on this object, anyone with read/write permissions is allowed to delete permissions
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.deleteAppSettingsPermissionByObjectIdAndAccessorId(
     *     {
     *       objectId: "...",
     *       accessorType:
     *         GetAppSettingsPermissionByObjectIdAndAccessorIdPathAccessorType.User,
     *       accessorId: "...",
     *     },
     *   );
     *
     * @throws {ErrorResponseError} No object available for the given objectId or the accessor doesn't have any permissions on this object
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteAppSettingsPermissionByObjectIdAndAccessorId(config: {
        /** The ID of the required settings object */ objectId: string;
        /** The type of the accessor */ accessorType: 'user' | 'group';
        /** The user uuid or group uuid of the accessor, depending on the type */ accessorId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Get current permissions of the all-users accessor on this object
     *
     * @returns {Promise<AppSettingsAccessorPermissions>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.getAppSettingsAllUsersPermissionByObjectId(
     *     { objectId: "..." },
     *   );
     *
     * @throws {ErrorResponseError} No object available for the given objectId or the all-users accessor doesn't have any permissions on this object
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getAppSettingsAllUsersPermissionByObjectId(config: {
        /** The ID of the required settings object */ objectId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsAccessorPermissions>;
    /**
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Update the permissions for an existing all-users accessor on this object, anyone with read/write permissions is allowed to update permissions
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.putAppSettingsAllUsersPermissionByObjectId(
     *     { objectId: "...", body: { permissions: {} } },
     *   );
     *
     * @throws {ErrorResponseError} if permission list is empty, contains unsupported entries or unsupported combinations of entries | No object available for the given objectId or the all-users accessor doesn't have any permissions on this object
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    putAppSettingsAllUsersPermissionByObjectId(config: {
        body: AppSettingsUpdatePermissionsRequest;
        /** The ID of the required settings object */ objectId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Remove the permissions for an existing all-users accessor on this object, anyone with read/write permissions is allowed to delete permissions
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.deleteAppSettingsAllUsersPermissionByObjectId(
     *     { objectId: "..." },
     *   );
     *
     * @throws {ErrorResponseError} No object available for the given objectId or the all-users accessor doesn't have any permissions on this object
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteAppSettingsAllUsersPermissionByObjectId(config: {
        /** The ID of the required settings object */ objectId: string;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Lists persisted settings objects
     *
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Lists persisted settings objects for selected schemas.
     *
     * If nothing is persisted or if all persisted settings objects are not accessible due to missing permissions, no items will be returned.
     *
     * To query the effective values (including schema defaults) please see [getEffectiveAppSettingsValues](#geteffectiveappsettingsvalues).
     *
     * Properties of type **secret** will be included in plain text if the call originates from a serverless function of your app; they will have irreversibly masked values otherwise. This protects these secrets from leaking to users of your app or other third parties.
     *
     * @returns {Promise<AppSettingsObjectsList>} Success. Uses chunked encoding.
     *
     *  Even if a response returns a successful response code it is possible that the result is incomplete due to an internal error.
     *
     *  In this case an 'error' property with information about the problem is added. The caller may decide to work with the incomplete result or do a retry of the operation.
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.getAppSettingsObjects();
     *
     * @throws {ErrorResponseError} Failed. The input is invalid. | Failed. Forbidden. | Failed. The specified schema was not found.
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getAppSettingsObjects(config?: {
        /**
         * Schema ID to which the requested objects belong.
         *
         * To load the first page, when the **nextPageKey** is not set, this parameter is required.
         */ schemaId?: string;
        /**
         * A list of fields to be included to the response. The provided set of fields extends the default set.
         *
         *  Specify the required top-level fields, separated by commas (for example, **summary,value**).
         *
         * Supported fields: **objectId**, **version**, **summary**, **searchSummary**, **schemaId**, **schemaVersion**, **modificationInfo**, **resourceContext**, **value**, **owner**.
         *
         *  Default fields: objectId, version.
         */ addFields?: string;
        /**
         * The filter parameter, as explained [here](https://dt-url.net/platform-services-filtering).
         *
         *  Filtering is supported on the following fields:
         *  * `modificationInfo.createdBy`
         *  * `modificationInfo.createdTime`
         *  * `modificationInfo.lastModifiedBy`
         *  * `modificationInfo.lastModifiedTime`
         *  * `value` with properties and sub-properties separated by dot (for example, `value.owningApp = 'Notebooks'`)
         *  * `owner.type`
         *  * `owner.id`
         *
         *  If this parameter is omitted, all settings objects will be returned. The maximum nesting depth (via parentheses) is 5. The maximum expression length is 1024 characters.
         *
         *  Note that only fields included to the response via `add-fields` can be used for filtering.
         */ filter?: string;
        /**
         * The sort parameter, as explained [here](https://dt-url.net/platform-services-filtering).
         *
         *  Sorting is supported on the following fields:
         *  * `modificationInfo.createdBy`
         *  * `modificationInfo.createdTime`
         *  * `modificationInfo.lastModifiedBy`
         *  * `modificationInfo.lastModifiedTime`
         *  * `value` with properties and sub-properties separated by dot (for example, `value.owningApp`)
         *
         *  Note that only fields included to the response via `add-fields` can be used for sorting.
         */ sort?: string;
        /**
         * The cursor for the next page of results. You can find it in the **nextPageKey** field of the previous response.
         *
         * The first page is always returned if you don't specify the **page-key** query parameter.
         *
         * When the **page-key** is set to obtain subsequent pages, you must omit all other query parameters.
         */ pageKey?: string;
        /**
         * The amount of settings objects in a single response payload.
         *
         * If set to 0, all available settings objects will be included in the response (not allowed if filter or sort parameter is referencing `value`).
         *
         * The maximal allowed page size is 500.
         *
         * If not set, 100 is used.
         */ pageSize?: number;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsObjectsList>;
    /**
     * Creates a new settings object
     *
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Creates a new settings object.
     *
     * @returns {Promise<AppSettingsObjectResponse | void>} Created
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.postAppSettingsObject({
     *     body: { schemaId: "jira-connection", value: {} },
     *   });
     *
     * @throws {ErrorResponseError} Failed. The input is invalid. | Failed. Forbidden. | Failed. The requested resource doesn't exist.
     * @throws {ConflictingResource} Failed. Conflicting resource.
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    postAppSettingsObject(config: {
        body: AppSettingsObjectCreate;
        /** If `true`, the request runs only validation of the submitted settings objects, without saving them. */ validateOnly?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsObjectResponse | void>;
    /**
     * Lists effective settings values
     *
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Lists effective settings values for selected schemas.
     * If no object is persisted for a schema with **"multiObject": false**, the default value as defined in the schema will be returned.
     *
     * Properties of type **secret** will be included in plain text if the call originates from a serverless function of your app; they will have irreversibly masked values otherwise. This protects these secrets from leaking to users of your app or other third parties.
     *
     * @returns {Promise<EffectiveAppSettingsValuesList>} Success. Uses chunked encoding.
     *
     *  Even if a response returns a successful response code it is possible that the result is incomplete due to an internal error.
     *
     *  In this case an 'error' property with information about the problem is added. The caller may decide to work with the incomplete result or do a retry of the operation.
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.getEffectiveAppSettingsValues();
     *
     * @throws {ErrorResponseError} Failed. The input is invalid. | Failed. The specified schema is not found.
     * @throws {TooManyRequests} Failed. Too many requests.
     * @throws {ServiceUnavailable} Failed. Service unavailable.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getEffectiveAppSettingsValues(config?: {
        /**
         * Schema ID to which the requested objects belong.
         *
         * Only considered on load of the first page, when the **nextPageKey** is not set.
         */ schemaId?: string;
        /**
         * A list of fields to be included to the response. The provided set of fields extends the default set.
         *
         *  Specify the required top-level fields, separated by commas (for example, **summary,schemaId**).
         *
         * Supported fields: **summary**, **searchSummary**, **schemaId**, **schemaVersion**, **modificationInfo**, **value**.
         *
         *  Default fields: value.
         */ addFields?: string;
        /**
         * The cursor for the next page of results. You can find it in the **nextPageKey** field of the previous response.
         *
         * The first page is always returned if you don't specify the **page-key** query parameter.
         *
         * When the **page-key** is set to obtain subsequent pages, you must omit all other query parameters.
         */ pageKey?: string;
        /**
         * The amount of settings objects in a single response payload.
         *
         * If set to 0, all available settings objects will be included in the response.
         *
         * The maximal allowed page size is 500.
         *
         * If not set, 100 is used.
         */ pageSize?: number;
        /** If set to true and user has app-settings:objects:admin permission, the endpoint will act as if the user is the owner of all objects */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<EffectiveAppSettingsValuesList>;
    /**
     * Get the effective settings permissions of the calling user in the environment
     *
     * **Required scope:** app-settings:objects:read or app-settings:objects:write<br/>**Required permission:** app-settings:objects:read or app-settings:objects:write
     *
     * @returns {Promise<EffectivePermissions>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings-v2";
     *
     * const data =
     *   await appSettingsObjectsClient.resolveEffectivePermissions(
     *     {
     *       body: {
     *         permissions: [
     *           {
     *             permission:
     *               SinglePermissionRequestPermission.AppSettingsObjectsRead,
     *             context: { schemaId: "..." },
     *           },
     *         ],
     *       },
     *     },
     *   );
     *
     * @throws {ErrorResponseError} Failed. The input is invalid. | Failed. Forbidden. No access to any schema.
     * @throws {GeneralError} Error.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    resolveEffectivePermissions(config: {
        body: ResolutionRequest;
        abortSignal?: AbortSignal;
    }): Promise<EffectivePermissions>;
}
export declare const appSettingsObjectsClient: AppSettingsObjectsClient;
