import { AbortSignal, HttpClient } from '@dynatrace-sdk/http-client';
import { AppSettingsObject } from '../models/app-settings-object';
import { AppSettingsObjectCreate } from '../models/app-settings-object-create';
import { AppSettingsObjectResponse } from '../models/app-settings-object-response';
import { AppSettingsObjectUpdate } from '../models/app-settings-object-update';
import { AppSettingsObjectsList } from '../models/app-settings-objects-list';
import { EffectiveAppSettingsValuesList } from '../models/effective-app-settings-values-list';
import { EffectivePermissions } from '../models/effective-permissions';
import { ResolutionRequest } from '../models/resolution-request';
import { ApiClientOptions } from './api-client-options';
/**
 * Manage settings objects for apps
 */
export declare class AppSettingsObjectsClient {
    private httpClient;
    private shouldTransformDates;
    /**
     * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a AppSettingsObjectsClient. Custom http client should implement {HttpClient} interface.
     * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
     * @example
     * const appSettingsObjectsClientNodeJs = new AppSettingsObjectsClient(yourCustomImplementation);
     */
    constructor(httpClientImplementation: HttpClient, options?: ApiClientOptions);
    /**
     * Gets the specified settings object
     *
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Gets the specified settings object. Properties of type **secret** will be included in plain text if the call originates from a serverless function of your app; they will have irreversibly masked values otherwise. This protects these secrets from leaking to users of your app or other third parties.
     *
     * @deprecated
     *
     * @returns {Promise<AppSettingsObject>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings";
     *
     * const data =
     *   await appSettingsObjectsClient.getAppSettingsObjectByObjectId(
     *     { objectId: "..." },
     *   );
     *
     * @throws {AppSettingsErrorEnvelopeError} Failed. The input is invalid. | Failed. Forbidden. | No object available for the given objectId
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getAppSettingsObjectByObjectId(config: {
        /** The ID of the required settings object. */ objectId: string;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsObject>;
    /**
     * Updates an existing settings object
     *
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Updates an existing settings object with new values. To update a property of the `secret` type you need to pass the new value unmasked. To keep the current value, send the current masked secret. You can obtain it via [GET an object](https://dt-url.net/kj036oj) endpoint.
     *
     * Some schemas don't allow passing of the masked secret. In that case you need to send the unmasked secret with every update of the object.
     *
     * @deprecated
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings";
     *
     * const data =
     *   await appSettingsObjectsClient.putAppSettingsObjectByObjectId(
     *     {
     *       objectId: "...",
     *       optimisticLockingVersion: "...",
     *       body: { value: {} },
     *     },
     *   );
     *
     * @throws {AppSettingsErrorEnvelopeError} Failed. The input is invalid. | Failed. Forbidden. | Failed. The requested resource doesn't exist. | Failed. Conflicting resource.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    putAppSettingsObjectByObjectId(config: {
        body: AppSettingsObjectUpdate;
        /** The ID of the required settings object. */ objectId: string;
        /**
         * The version of the object for optimistic locking. You can use it to detect simultaneous modifications by different users.
         *
         * It is generated upon retrieval (GET requests). If set on update (PUT request) or deletion, the update/deletion will be allowed only if there wasn't any change between the retrieval and the update.
         */ optimisticLockingVersion: string;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Deletes the specified settings object
     *
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write
     *
     * @deprecated
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings";
     *
     * const data =
     *   await appSettingsObjectsClient.deleteAppSettingsObjectByObjectId(
     *     { objectId: "...", optimisticLockingVersion: "..." },
     *   );
     *
     * @throws {AppSettingsErrorEnvelopeError} Failed. The input is invalid. | Failed. Forbidden. | Failed. The requested resource doesn't exist. | Failed. Conflicting resource.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteAppSettingsObjectByObjectId(config: {
        /** The ID of the required settings object. */ objectId: string;
        /**
         * The version of the object for optimistic locking. You can use it to detect simultaneous modifications by different users.
         *
         * It is generated upon retrieval (GET requests). If set on update (PUT request) or deletion, the update/deletion will be allowed only if there wasn't any change between the retrieval and the update.
         */ optimisticLockingVersion: string;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Lists persisted settings objects
     *
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Lists persisted settings objects for selected schemas.
     *
     * If nothing is persisted or if all persisted settings objects are not accessible due to missing permissions, no items will be returned.
     *
     * To query the effective values (including schema defaults) please see [getEffectiveAppSettingsValues](#geteffectiveappsettingsvalues).
     *
     * Properties of type **secret** will be included in plain text if the call originates from a serverless function of your app; they will have irreversibly masked values otherwise. This protects these secrets from leaking to users of your app or other third parties.
     *
     * @deprecated
     *
     * @returns {Promise<AppSettingsObjectsList>} Success. Accessible objects returned.
     *
     *  Even if a response returns a successful response code it is possible that the result is incomplete due to an internal error.
     *
     *  In this case an 'error' property with information about the problem is added. The caller may decide to work with the incomplete result or do a retry of the operation.
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings";
     *
     * const data =
     *   await appSettingsObjectsClient.getAppSettingsObjects();
     *
     * @throws {AppSettingsErrorEnvelopeError} Failed. The input is invalid. | Failed. Forbidden. | Failed. The specified schema was not found.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getAppSettingsObjects(config?: {
        /**
         * A list of comma-separated schema IDs to which the requested objects belong.
         *
         * To load the first page, when the **nextPageKey** is not set, this parameter is required.
         */ schemaIds?: string;
        /**
         * A list of fields to be included to the response. The provided set of fields extends the default set.
         *
         *  Specify the required top-level fields, separated by commas (for example, **summary,value**).
         *
         * Supported fields: **objectId**, **version**, **summary**, **searchSummary**, **schemaId**, **schemaVersion**, **modificationInfo**, **resourceContext**, **value**.
         *
         *  Default fields: objectId, version.
         */ addFields?: string;
        /**
         * The cursor for the next page of results. You can find it in the **nextPageKey** field of the previous response.
         *
         * The first page is always returned if you don't specify the **page-key** query parameter.
         *
         * When the **page-key** is set to obtain subsequent pages, you must omit all other query parameters.
         */ pageKey?: string;
        /**
         * The amount of settings objects in a single response payload.
         *
         * The maximal allowed page size is 500.
         *
         * If not set, 100 is used.
         */ pageSize?: number;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsObjectsList>;
    /**
     * Creates a new settings object
     *
     * **Required scope:** app-settings:objects:write<br/>**Required permission:** app-settings:objects:write<br/><br/>Creates a new settings object.
     *
     * @deprecated
     *
     * @returns {Promise<AppSettingsObjectResponse | void>} Created
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings";
     *
     * const data =
     *   await appSettingsObjectsClient.postAppSettingsObject({
     *     body: { schemaId: "jira-connection", value: {} },
     *   });
     *
     * @throws {AppSettingsErrorEnvelopeError} Failed. The input is invalid. | Failed. Forbidden. | Failed. The requested resource doesn't exist. | Failed. Conflicting resource.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    postAppSettingsObject(config: {
        body: AppSettingsObjectCreate;
        /** If `true`, the request runs only validation of the submitted settings objects, without saving them. */ validateOnly?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<AppSettingsObjectResponse | void>;
    /**
     * Lists effective settings values
     *
     * **Required scope:** app-settings:objects:read<br/>**Required permission:** app-settings:objects:read<br/><br/>Lists effective settings values for selected schemas.
     * If no object is persisted for a schema with **"multiObject": false**, the default value as defined in the schema will be returned.
     *
     * Properties of type **secret** will be included in plain text if the call originates from a serverless function of your app; they will have irreversibly masked values otherwise. This protects these secrets from leaking to users of your app or other third parties.
     *
     * @deprecated
     *
     * @returns {Promise<EffectiveAppSettingsValuesList>} Success
     *
     *  Even if a response returns a successful response code it is possible that the result is incomplete due to an internal error.
     *
     *  In this case an 'error' property with information about the problem is added. The caller may decide to work with the incomplete result or do a retry of the operation.
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings";
     *
     * const data =
     *   await appSettingsObjectsClient.getEffectiveAppSettingsValues();
     *
     * @throws {AppSettingsErrorEnvelopeError} Failed. The input is invalid. | Failed. The specified schema is not found.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getEffectiveAppSettingsValues(config?: {
        /**
         * A list of comma-separated schema IDs to which the requested objects belong.
         *
         * Only considered on load of the first page, when the **nextPageKey** is not set.
         */ schemaIds?: string;
        /**
         * A list of fields to be included to the response. The provided set of fields extends the default set.
         *
         *  Specify the required top-level fields, separated by commas (for example, **summary,schemaId**).
         *
         * Supported fields: **summary**, **searchSummary**, **schemaId**, **schemaVersion**, **modificationInfo**, **value**.
         *
         *  Default fields: value.
         */ addFields?: string;
        /**
         * The cursor for the next page of results. You can find it in the **nextPageKey** field of the previous response.
         *
         * The first page is always returned if you don't specify the **page-key** query parameter.
         *
         * When the **page-key** is set to obtain subsequent pages, you must omit all other query parameters.
         */ pageKey?: string;
        /**
         * The amount of settings objects in a single response payload.
         *
         * The maximal allowed page size is 500.
         *
         * If not set, 100 is used.
         */ pageSize?: number;
        abortSignal?: AbortSignal;
    }): Promise<EffectiveAppSettingsValuesList>;
    /**
     * Get the effective settings permissions of the calling user in the environment
     *
     * **Required scope:** app-settings:objects:read or app-settings:objects:write<br/>**Required permission:** app-settings:objects:read or app-settings:objects:write
     *
     * @deprecated
     *
     * @returns {Promise<EffectivePermissions>} Success
     *
     * @example <caption>Code example</caption>
     * import { appSettingsObjectsClient } from "@dynatrace-sdk/client-app-settings";
     *
     * const data =
     *   await appSettingsObjectsClient.resolveEffectivePermissions(
     *     {
     *       body: {
     *         permissions: [
     *           {
     *             permission:
     *               SinglePermissionRequestPermission.AppSettingsObjectsRead,
     *             context: { schemaId: "..." },
     *           },
     *         ],
     *       },
     *     },
     *   );
     *
     * @throws {AppSettingsErrorEnvelopeError} Failed. The input is invalid. | Failed. Forbidden. No access to any schema. | Failed.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    resolveEffectivePermissions(config: {
        body: ResolutionRequest;
        abortSignal?: AbortSignal;
    }): Promise<EffectivePermissions>;
}
export declare const appSettingsObjectsClient: AppSettingsObjectsClient;
