import { AbortSignal, HttpClient } from '@dynatrace-sdk/http-client';
import { AcquireLock } from '../models/acquire-lock';
import { AcquireLockResult } from '../models/acquire-lock-result';
import { DocumentLockDetails } from '../models/document-lock-details';
import { ApiClientOptions } from './api-client-options';
/**
 * Endpoints for document locking.
 */
export declare class DocumentLockingClient {
    private httpClient;
    private shouldTransformDates;
    /**
     * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a DocumentLockingClient. Custom http client should implement {HttpClient} interface.
     * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
     * @example
     * const documentLockingClientNodeJs = new DocumentLockingClient(yourCustomImplementation);
     */
    constructor(httpClientImplementation: HttpClient, options?: ApiClientOptions);
    /**
     * Inspect whether the document is locked.
     *
     * **Required scope:** document:documents:read<br/><br/>Inspect whether the document is locked.
     *
     * This provides the information about whether the document is locked and the user that currently owns the lock.
     *
     * @returns {Promise<DocumentLockDetails>} Lock details for a document.
     *
     * @example <caption>Code example</caption>
     * import { documentLockingClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentLockingClient.inspectLock({
     *   id: "...",
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    inspectLock(config: {
        /** System-generated id of a document. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<DocumentLockDetails>;
    /**
     * Acquire the lock on the document.
     *
     * **Required scope:** document:documents:write<br/><br/>Acquire the lock on the document. A user can lock a maximum of five documents at any given time. Once the lock is acquired by the user, other users cannot make any updates to the document.
     *
     * The user acquiring the lock can optionally specify the duration for which the lock can be attained. However, the specified duration must not exceed the maximum allowed duration of 15 minutes. If not specified, the lock is acquired for 10 minutes.
     *
     * If the user who has currently locked the document attempts to acquire the lock for the same document again, the duration of the lock gets extended by the specified duration or by a default duration of 10 minutes, if not specified.
     *
     * The other users would not be allowed to acquire the lock on an already locked document.
     *
     * @returns {Promise<AcquireLockResult>} The lock has been acquired by the user.
     *
     * @example <caption>Code example</caption>
     * import { documentLockingClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentLockingClient.acquireLock({
     *   id: "...",
     *   body: { documentVersion: 10 },
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {DocumentAlreadyLocked} Lock acquisition failed as the document is already locked.
     * @throws {LockedDocumentsLimitReached} Lock acquisition failed as number of locked documents reached or exceeded the allowed limit.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    acquireLock(config: {
        body: AcquireLock;
        /** System-generated id of a document. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<AcquireLockResult>;
    /**
     * Release the lock on the document.
     *
     * **Required scope:** document:documents:write<br/><br/>Release the lock on the document.
     * The lock on the document can be released only by the user who owns it.
     *
     * @example <caption>Code example</caption>
     * import { documentLockingClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentLockingClient.releaseLock({
     *   id: "...",
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    releaseLock(config: {
        /** System-generated id of a document. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<void>;
}
export declare const documentLockingClient: DocumentLockingClient;
