import { AbortSignal, Binary, HttpClient } from '@dynatrace-sdk/http-client';
import { BulkDeleteRequest } from '../models/bulk-delete-request';
import { BulkDeleteResponse } from '../models/bulk-delete-response';
import { CreateDocumentBody } from '../models/create-document-body';
import { DocumentList } from '../models/document-list';
import { DocumentMetaData } from '../models/document-meta-data';
import { GetDocumentResponse } from '../models/get-document-response';
import { RestoreDocumentResult } from '../models/restore-document-result';
import { SnapshotList } from '../models/snapshot-list';
import { SnapshotMetadata } from '../models/snapshot-metadata';
import { TransferOwner } from '../models/transfer-owner';
import { UpdateDocumentBody } from '../models/update-document-body';
import { UpdateDocumentContentBody } from '../models/update-document-content-body';
import { UpdateDocumentMetadata } from '../models/update-document-metadata';
import { UpdateDocumentMetadataBody } from '../models/update-document-metadata-body';
import { ApiClientOptions } from './api-client-options';
/**
 * CRUD operations for documents and snapshots.
 */
export declare class DocumentsClient {
    private httpClient;
    private shouldTransformDates;
    /**
     * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a DocumentsClient. Custom http client should implement {HttpClient} interface.
     * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
     * @example
     * const documentsClientNodeJs = new DocumentsClient(yourCustomImplementation);
     */
    constructor(httpClientImplementation: HttpClient, options?: ApiClientOptions);
    /**
     * List all documents accessible to you.
     *
     * **Required scope:** document:documents:read<br/><br/>List the metadata of all documents accessible to you.
     *
     *
     * This includes your own documents, as well as other users' documents which have been shared with you.
     *
     *
     * *Note, that at the moment we offer a naive pagination, and therefore interim document mutations and/or an
     * insufficient sort clause, if provided, can lead to result inconsistencies (such as duplicates, missing entries).*
     *
     * @returns {Promise<DocumentList>} A list of metadata objects of documents which are accessible to you.
     *
     * Note, that this includes your own documents as well as other users' documents which are shared with you.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.listDocuments();
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    listDocuments(config?: {
        /**
         * The filter parameter, as explained [here](https://dt-url.net/platform-services-filtering).
         *
         * If this parameter is omitted, no filtering is applied and all documents available to you will be returned.
         *
         * Filtering by string type parameters (`name`, `type`) when using one of the operators `contains`, `starts-with` and `ends-with` is **case insensitive**.
         *
         * When using the equals operator or the not-equals operator, filtering is **case sensitive**.
         *
         * The following fields are legal filtering parameters - any other field names will result in a HTTP 400 response:
         *
         * `id`, `name`, `type`, `version`, `owner`, `modificationInfo.createdTime`, `modificationInfo.createdBy`, `modificationInfo.lastModifiedTime`, `modificationInfo.lastModifiedBy`, `externalId`, `originAppId`, `originExtensionId`
         *
         * The following constraints apply:
         *
         * * Parameter names are **case-sensitive**.
         *
         * * Maximum nesting depth (via brackets) is 3.
         *
         * * Maximum length is 256 characters.
         *
         * Examples:
         *
         * * `name = 'my-document-name'`
         *
         * * `name == 'my-document-name'`
         *
         * * `(name starts-with 'awesome' or type != 'dashboard') and version >= 5`
         *
         * * `modificationInfo.lastModifiedTime >= '2022-07-01T00:10:05.000Z' and not (name contains 'new')`
         *
         * * `originAppId exists`
         *
         * * `originExtensionId exists`
         */ filter?: string;
        /**
         * The sort parameter, as explained [here](https://dt-url.net/platform-services-filtering)
         *
         * If this parameter is omitted, the documents are sorted by their ids.
         *
         * Sorting by string types (`name`, `type`) is done in a case insensitive manner.
         *
         * The following fields are legal sorting parameters - any other sorting parameters will result in a HTTP 400 response:
         * * `name`,  `type`,  `version`, `owner`, `modificationInfo.createdTime`, `modificationInfo.createdBy`, `modificationInfo.lastModifiedTime`,`modificationInfo.lastModifiedBy`,`originAppId`, `userContext.lastAccessedTime`
         *
         * The following constraints apply:
         *
         * * Maximum number of sorting parameters is 5. Exceeding this limit will result in a HTTP 400 response.
         *
         * * Note that blanks are *not* ignored and will result in a HTTP 400 response.
         *
         * Examples:
         *
         * * `name`
         *
         * * `name,-type,modificationInfo.lastModifiedTime`
         */ sort?: string;
        /**
         * The page key is used to query results from the next page.
         * You get a `nextPageKey` parameter in the return value of this method to use here.
         * If this parameter is omitted, the first page will be returned.
         */ pageKey?: string;
        /**
         * The page parameter is used to directly access a specific page.
         * The value of the page parameter, if specified, has to be a value greater than zero.
         * If the value of the page parameter exceeds the highest available page on the backend, an empty page is returned.
         */ page?: number;
        /**
         * The page size which defines the requested number of result entries. You can request a maximum of 1000 result entries.
         * If this parameter is omitted, the default value of 20 will be used.
         */ pageSize?: number;
        /**
         * Indicates whether the operation should be performed with elevated permissions - additionally requires **document:documents:admin**.
         *
         * If provided, the user has the same permissions as the document owner. This is not supported for ready-made documents.
         */ adminAccess?: boolean;
        /**
         * Comma-separated list of field names that are added to the default set of fields.
         * You can include the following additional fields:
         * - `description`
         * - `userContext.lastAccessedTime`
         * - `originExtensionId`
         */ addFields?: string;
        abortSignal?: AbortSignal;
    }): Promise<DocumentList>;
    /**
     * Create a new document.
     *
     * **Required scope:** document:documents:write<br/><br/>Create a new document which is then owned by you (the user specified by the provided Authorization header). The document is not accessible to other users.
     *
     * The document's `name` and `type` must be provided. These two properties can later be used for filtering purposes, when [listing accessible documents](#/Documents/listDocuments).
     *
     * Be aware, that the `type` is not the same as the Content-Type of the document, but instead adds user-defined semantics of which the document-store is entirely agnostic.
     *
     * The content size must not exceed **50 MB**.
     *
     * @returns {Promise<DocumentMetaData>} A new document has been created.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.createDocument({
     *   body: { name: "...", type: "...", content: "..." },
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentTooLarge} Maximum content size exceeded.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InsufficientStorage} The storage quota or maximum number of documents has been exceeded.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    createDocument(config: {
        body: CreateDocumentBody;
        abortSignal?: AbortSignal;
    }): Promise<DocumentMetaData>;
    /**
     * Retrieve metadata and content.
     *
     * **Required scope:** document:documents:read<br/><br/>Return metadata and content in one multipart response.
     *
     * If the `snapshot-version` param is provided, the metadata and content of the specified snapshot gets returned instead. This requires write-access to the document.
     *
     * The document must be accessible to you - therefore, you must either own it or you have received access through sharing.
     *
     * @returns {Promise<GetDocumentResponse>} Metadata and content in a multipart response.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.getDocument({
     *   id: "...",
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentOrSnapshotNotFound} Document or snapshot not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getDocument(config: {
        /** System-generated id of a document. */ id: string;
        /** The optional `filename` query parameter can be passed to give the file that is being downloaded a user-provided name and file extension for downloading purposes. This name will be sent back to the client via the Content-Disposition HTTP header. The passed `filename` will be trimmed that it does not contain any space characters around the name. When the `filename` is not specified, then the name of the document is used as file name and no extension is added, since the service is not aware of file extensions. */ filename?: string;
        /** Snapshot version, to be used if you want to access a snapshot of the document. */ snapshotVersion?: number;
        /**
         * Indicates whether the operation should be performed with elevated permissions - additionally requires **document:documents:admin**.
         *
         * If provided, the user has the same permissions as the document owner. This is not supported for ready-made documents.
         */ adminAccess?: boolean;
        /**
         * Comma-separated list of field names that are added to the default set of fields.
         * You can include the following additional fields:
         * - `userContext.lastAccessedTime`
         */ addFields?: string;
        abortSignal?: AbortSignal;
    }): Promise<GetDocumentResponse>;
    /**
     * Delete the document
     *
     * **Required scope:** document:documents:delete<br/><br/>Move the document into the trash. It is no longer accessible until it's restored from the trash.
     *
     * [Optimistic locking](https://dt-url.net/platform-services-locking) is enforced via the `optimistic-locking-version` parameter.
     *
     * You must own the document in order to delete it.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.deleteDocument({
     *   id: "...",
     *   optimisticLockingVersion: "...",
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {Conflict} Optimistic locking failed, or the document is actively locked by another user, or some other conflict.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteDocument(config: {
        /** System-generated id of a document. */ id: string;
        /** To protect users from accidental overrides, the current version of the document must match the optimistic locking version parameter - otherwise, this request will fail and the entity is left unchanged. */ optimisticLockingVersion: string;
        /**
         * Indicates whether the operation should be performed with elevated permissions - additionally requires **document:documents:admin**.
         *
         * If provided, the user has the same permissions as the document owner. This is not supported for ready-made documents.
         */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Update metadata and content. Optionally, create a snapshot.
     *
     * **Required scope:** document:documents:write<br/><br/>Update metadata and/or the content of the document.
     *
     * Name, type and content must be non-empty, but are optional. At least one of them must be provided.
     *
     * The document must be accessible to you - therefore, you must either own it or you have received access through sharing.
     *
     * As part of this operation, you can optionally create a snapshot of the updated document.
     * In that case, if the document has more than 50 snapshots, its oldest snapshot gets automatically deleted.
     * It's not possible to create more than 5 snapshots per 60 seconds, per document.
     *
     * @returns {Promise<UpdateDocumentMetadata>} Result of updating metadata & content. Contains document metadata and snapshot metadata.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.updateDocument({
     *   id: "...",
     *   optimisticLockingVersion: "...",
     *   body: {},
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {SnapshotCreationRateLimitExceeded} Too many snapshots have been created for this document in the recent time. Try again later.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    updateDocument(config: {
        body: UpdateDocumentBody;
        /** System-generated id of a document. */ id: string;
        /** To protect users from accidental overrides, the current version of the document must match the optimistic locking version parameter - otherwise, this request will fail and the entity is left unchanged. */ optimisticLockingVersion: string;
        /** Indicates whether a new snapshot shall be created after the update was executed. */ createSnapshot?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<UpdateDocumentMetadata>;
    /**
     * Retrieve document metadata.
     *
     * **Required scope:** document:documents:read<br/><br/>Retrieve a document's metadata.
     *
     * The document must be accessible to you - therefore, you must either own it or you have received access through sharing.
     *
     * If the `snapshot-version` param is provided, the metadata of the specified snapshot gets returned instead. This requires write-access to the document.
     *
     * This endpoint supports external ids.
     *
     * @returns {Promise<DocumentMetaData>} Metadata of document
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.getDocumentMetadata({
     *   id: "...",
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentOrSnapshotNotFound} Document or snapshot not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getDocumentMetadata(config: {
        /** System-generated id or user-given external id of a document. */ id: string;
        /** Snapshot version, to be used if you want to access a snapshot of the document. */ snapshotVersion?: number;
        /**
         * Indicates whether the operation should be performed with elevated permissions - additionally requires **document:documents:admin**.
         *
         * If provided, the user has the same permissions as the document owner. This is not supported for ready-made documents.
         */ adminAccess?: boolean;
        /**
         * Comma-separated list of field names that are added to the default set of fields.
         * You can include the following additional fields:
         * - `userContext.lastAccessedTime`
         */ addFields?: string;
        abortSignal?: AbortSignal;
    }): Promise<DocumentMetaData>;
    /**
     * Update document metadata
     *
     * **Required scope:** document:documents:write<br/><br/>Partially update a document's user-defined metadata. At least one property must be updated, otherwise the operation fails.
     *
     * The document's content is not affected by this operation.
     *
     * [Optimistic locking](https://dt-url.net/platform-services-locking) is enforced via the `optimistic-locking-version` parameter.
     *
     * The document must be accessible to you - therefore, you must either own it or you have received access through sharing.
     *
     * @returns {Promise<DocumentMetaData>} The document has been updated. The updated metadata is returned.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.updateDocumentMetadata({
     *   id: "...",
     *   optimisticLockingVersion: "...",
     *   body: {},
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {Conflict} Optimistic locking failed, or the document is actively locked by another user, or some other conflict.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    updateDocumentMetadata(config: {
        body: UpdateDocumentMetadataBody;
        /** System-generated id of a document. */ id: string;
        /** To protect users from accidental overrides, the current version of the document must match the optimistic locking version parameter - otherwise, this request will fail and the entity is left unchanged. */ optimisticLockingVersion: string;
        abortSignal?: AbortSignal;
    }): Promise<DocumentMetaData>;
    /**
     * Download document content
     *
     * **Required scope:** document:documents:read<br/><br/>Download latest document content.
     *
     * If the `snapshot-version` param is provided, the content of the specified snapshot gets returned instead. This requires write-access to the document.
     *
     * The document must be accessible to you - therefore, you must either own it or you have received access through sharing.
     *
     * The response's `Content-Type` header has the same value that has been used during the upload.
     *
     * @returns {Promise<Binary>} Content of the document
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.downloadDocumentContent({
     *   id: "...",
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentOrSnapshotNotFound} Document or snapshot not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    downloadDocumentContent(config: {
        /** System-generated id of a document. */ id: string;
        /** The optional `filename` query parameter can be passed to give the file that is being downloaded a user-provided name and file extension for downloading purposes. This name will be sent back to the client via the Content-Disposition HTTP header. The passed `filename` will be trimmed that it does not contain any space characters around the name. When the `filename` is not specified, then the name of the document is used as file name and no extension is added, since the service is not aware of file extensions. */ filename?: string;
        /** Snapshot version, to be used if you want to access a snapshot of the document. */ snapshotVersion?: number;
        /**
         * Indicates whether the operation should be performed with elevated permissions - additionally requires **document:documents:admin**.
         *
         * If provided, the user has the same permissions as the document owner. This is not supported for ready-made documents.
         */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<Binary>;
    /**
     * Update document content
     *
     * **Required scope:** document:documents:write<br/><br/>Update a document's content, by completely replacing it.
     *
     * The document must be accessible to you - therefore, you must either own it or you have received access through sharing.
     *
     * [Optimistic locking](https://dt-url.net/platform-services-locking) is enforced via the `optimistic-locking-version` parameter.
     *
     * The content size must be greater than 0 and must not exceed `50 MB`.
     *
     * The `Content-Type` header must be set for the multipart part; it will be used as the (new) content type of the document. Illegal (non-mime-type) content types result in a `400 - Bad Request` error.
     *
     * The `Content-Disposition` header must be set for the multipart part;
     *
     * @returns {Promise<DocumentMetaData>} Document content successfully updated
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.updateDocumentContent({
     *   id: "...",
     *   optimisticLockingVersion: "...",
     *   body: { content: "..." },
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {Conflict} Optimistic locking failed, or the document is actively locked by another user, or some other conflict.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InsufficientStorage} The storage quota or maximum number of documents has been exceeded.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    updateDocumentContent(config: {
        body: UpdateDocumentContentBody;
        /** System-generated id of a document. */ id: string;
        /** To protect users from accidental overrides, the current version of the document must match the optimistic locking version parameter - otherwise, this request will fail and the entity is left unchanged. */ optimisticLockingVersion: string;
        abortSignal?: AbortSignal;
    }): Promise<DocumentMetaData>;
    /**
     * List all snapshots of the document
     *
     * **Required scope:** document:documents:read<br/><br/>Returns metadata of all snapshots of the document, in descending order of the snapshot's creation date. Requires write-access to the document.
     *
     * You can apply pagination via the `pageKey` and `pageSize` parameters.
     *
     * *Note, that at the moment we offer a naive pagination, and therefore interim mutations can lead to result inconsistencies (such as duplicates, missing entries).*
     *
     * @returns {Promise<SnapshotList>} A list of snapshots of the document.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.listSnapshots({
     *   id: "...",
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    listSnapshots(config: {
        /** System-generated id of a document. */ id: string;
        /**
         * The page key is used to query results from the next page.
         * You get a `nextPageKey` parameter in the return value of this method to use here.
         * If this parameter is omitted, the first page will be returned.
         */ pageKey?: string;
        /**
         * The page parameter is used to directly access a specific page.
         * The value of the page parameter, if specified, has to be a value greater than zero.
         * If the value of the page parameter exceeds the highest available page on the backend, an empty page is returned.
         */ page?: number;
        /**
         * The page size which defines the requested number of result entries. You can request a maximum of 1000 result entries.
         * If this parameter is omitted, the default value of 20 will be used.
         */ pageSize?: number;
        abortSignal?: AbortSignal;
    }): Promise<SnapshotList>;
    /**
     * Retrieve snapshot metadata.
     *
     * **Required scope:** document:documents:read<br/><br/>Retrieve snapshot metadata. Requires write-access to the document.
     *
     * This does not return data of the snapshotted document, instead it returns data about the snapshot itself.
     *
     * @returns {Promise<SnapshotMetadata>} Metadata of a specific snapshot.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.getSnapshotMetadata({
     *   id: "...",
     *   snapshotVersion: 10,
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {SnapshotNotFound} Snapshot not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getSnapshotMetadata(config: {
        /** System-generated id of a document. */ id: string;
        /** System-generated snapshot version. */ snapshotVersion: number;
        abortSignal?: AbortSignal;
    }): Promise<SnapshotMetadata>;
    /**
     * Delete the snapshot.
     *
     * **Required scope:** document:documents:write<br/><br/>Irrevocably delete the snapshot. Only the document owner may do this.
     *
     * This operation does not affect the current state of the document.
     *
     * Instead, it prevents that the document may ever be restored to the state it had when the snapshot was created.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.deleteSnapshot({
     *   id: "...",
     *   snapshotVersion: 10,
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {SnapshotNotFound} Snapshot not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteSnapshot(config: {
        /** System-generated id of a document. */ id: string;
        /** System-generated snapshot version. */ snapshotVersion: number;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Restore the snapshot.
     *
     * **Required scope:** document:documents:write<br/><br/>Reset the document to the state it had when the snapshot was created. Requires write-access to the document.
     *
     * If no snapshot of the current document state exists, then a new snapshot is created
     * before restoring the selected snapshot.
     * If the document has more than 50 snapshots, its oldest snapshot gets automatically deleted.
     *
     * This operation only changes the document's content. It doesn't change ownership or access/sharing data.
     *
     * @returns {Promise<RestoreDocumentResult>} Document has been restored. New snapshot has been created.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.restoreSnapshot({
     *   id: "...",
     *   snapshotVersion: 10,
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentOrSnapshotNotFound} Document or snapshot not found.
     * @throws {Conflict} Optimistic locking failed, or the document is actively locked by another user, or some other conflict.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    restoreSnapshot(config: {
        /** System-generated id of a document. */ id: string;
        /** System-generated snapshot version. */ snapshotVersion: number;
        abortSignal?: AbortSignal;
    }): Promise<RestoreDocumentResult>;
    /**
     * Transfers ownership of the document to a new owner.
     *
     * **Required scope:** document:documents:write<br/><br/>Transfers ownership of the document to a new owner. The previous owner loses access to the document. This operation can only be performed by the document owner.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.transferDocumentOwner({
     *   id: "...",
     *   body: { newOwnerId: "..." },
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    transferDocumentOwner(config: {
        body: TransferOwner;
        /** System-generated id of a document. */ id: string;
        /**
         * Indicates whether the operation should be performed with elevated permissions - additionally requires **document:documents:admin**.
         *
         * If provided, the user has the same permissions as the document owner. This is not supported for ready-made documents.
         */ adminAccess?: boolean;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Bulk-delete multiple documents
     *
     * **Required scope:** document:documents:delete<br/><br/>Move the documents with the given IDs into the trash. They are no longer accessible until they're restored from the trash.
     *
     * @returns {Promise<BulkDeleteResponse>} Result of the bulk operation for the individual objects.
     *
     * @example <caption>Code example</caption>
     * import { documentsClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await documentsClient.bulkDeleteDocument({
     *   body: { ids: ["..."] },
     * });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    bulkDeleteDocument(config: {
        body: BulkDeleteRequest;
        abortSignal?: AbortSignal;
    }): Promise<BulkDeleteResponse>;
}
export declare const documentsClient: DocumentsClient;
