import { AbortSignal, HttpClient } from '@dynatrace-sdk/http-client';
import { CreateEnvShare } from '../models/create-env-share';
import { EnvironmentShare } from '../models/environment-share';
import { EnvironmentShareClaimResult } from '../models/environment-share-claim-result';
import { EnvironmentShareClaimerList } from '../models/environment-share-claimer-list';
import { EnvironmentShareList } from '../models/environment-share-list';
import { ApiClientOptions } from './api-client-options';
/**
 * Share your documents with the whole environment, via links.
 */
export declare class EnvironmentSharesClient {
    private httpClient;
    private shouldTransformDates;
    /**
     * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a EnvironmentSharesClient. Custom http client should implement {HttpClient} interface.
     * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
     * @example
     * const environmentSharesClientNodeJs = new EnvironmentSharesClient(yourCustomImplementation);
     */
    constructor(httpClientImplementation: HttpClient, options?: ApiClientOptions);
    /**
     * List your environment-shares.
     *
     * **Required scope:** document:environment-shares:read<br/><br/>List all environment-shares of your own documents.
     *
     * If you are only concerned with a specific document's environment-shares, or a specific share, you can use the `filter` parameter to narrow down the result set. Note, that this does *not* circumvent the restriction of being able to only get environment-shares of *your own* documents. If you attempt to retrieve environment-shares of another user's document, the result set will be empty.
     *
     * Furthermore, you can apply pagination via the `pageKey`, `page` and `pageSize` parameters.
     *
     * *Note, that at the moment we offer a naive pagination, and therefore interim mutations can lead to result inconsistencies (such as duplicates, missing entries).*
     *
     * @returns {Promise<EnvironmentShareList>} A list of your environment-shares.
     * If the list was paginated (see `pageKey`, `page` and `pageSize`), and there are more environment-shares available, you will find a non-empty `nextPageKey` which can be used for a follow-up query. The `totalCount` property will let you know the number of all matching environment-shares, as if no pagination would have been applied.
     *
     * @example <caption>Code example</caption>
     * import { environmentSharesClient } from "@dynatrace-sdk/client-document";
     *
     * const data =
     *   await environmentSharesClient.listEnvironmentShares();
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    listEnvironmentShares(config?: {
        /** The filter query, as explained [here](https://dt-url.net/platform-services-filtering). Filtering is only possible on the `documentId` property, and only via the equals operator. Via this you can effectively request all shares of a specific document owned by you. If this parameter is omitted, all environment-shares of this user will be returned. */ filter?: string;
        /**
         * The page key is used to query results from the next page.
         * You get a `nextPageKey` parameter in the return value of this method to use here.
         * If this parameter is omitted, the first page will be returned.
         */ pageKey?: string;
        /**
         * The page parameter is used to directly access a specific page.
         * The value of the page parameter, if specified, has to be a value greater than zero.
         * If the value of the page parameter exceeds the highest available page on the backend, an empty page is returned.
         */ page?: number;
        /**
         * The page size which defines the requested number of result entries. You can request a maximum of 1000 result entries.
         * If this parameter is omitted, the default value of 20 will be used.
         */ pageSize?: number;
        abortSignal?: AbortSignal;
    }): Promise<EnvironmentShareList>;
    /**
     * Create an environment-share for one of your own documents.
     *
     * **Required scope:** document:environment-shares:write<br/><br/>Create a document share, which can be used to give one or multiple other users access to this document.
     *
     * This is only possible if you are the owner of the document.
     *
     * A share can be created with either `read` or `read-write` access.
     *
     * A document can have maximally one share per access type, therefore it's not possible to create multiple read-shares or multiple 'read-write'-shares for a single document.
     *
     * This means, that you can create one read-share for a document, and this single read-share can be used to give read-access to an arbitrary number of users. The same applies to a 'read-write'-share.
     *
     * Creating a share does *not* automatically allow users to access the document - only those users who explicitly [claim the share](#/Environment%20Shares/claimEnvironmentShare) gain access to the document.
     *
     * Revoking access from users can be done by [deleting the share](#/Environment%20Shares/deleteEnvironmentShare).
     *
     * @returns {Promise<EnvironmentShare>} A new share for the specified document has been created.
     *
     * @example <caption>Code example</caption>
     * import { environmentSharesClient } from "@dynatrace-sdk/client-document";
     *
     * const data =
     *   await environmentSharesClient.createEnvironmentShare({
     *     body: { documentId: "...", access: "..." },
     *   });
     *
     * @throws {BadRequest} Malformed request or invalid parameters.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {DocumentNotFound} Document not found.
     * @throws {ShareAlreadyExists} Share creation failed - a share with the specified permission already exists for the document.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    createEnvironmentShare(config: {
        body: CreateEnvShare;
        abortSignal?: AbortSignal;
    }): Promise<EnvironmentShare>;
    /**
     * Retrieve one of your environment-shares.
     *
     * **Required scope:** document:environment-shares:read<br/><br/>Retrieve a share via its id.
     *
     * Only the share's owner is permitted to do this.
     *
     * @returns {Promise<EnvironmentShare>} An environment-share.
     *
     * @example <caption>Code example</caption>
     * import { environmentSharesClient } from "@dynatrace-sdk/client-document";
     *
     * const data =
     *   await environmentSharesClient.getEnvironmentShare({
     *     id: "...",
     *   });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {ShareNotFound} Share not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getEnvironmentShare(config: {
        /** Environment-share id. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<EnvironmentShare>;
    /**
     * Delete one of your environment-shares.
     *
     * **Required scope:** document:environment-shares:delete<br/><br/>Delete the share. This will *not* delete the share's document.
     *
     * Only the share's owner is permitted to do this.
     *
     * This operation effectively revokes the access which has been granted to *all users* which have claimed this share. This is the only way to revoke access to your document from other users. It's not possible to revoke access of individual users.
     *
     * Be aware that deleting a share does not necessarily prevent a user from accessing a document, as the user might still have access via another share (of the same document). E.g., if a user has read- and readwrite-access (via one read-share and another readwrite-share), and the read-share gets deleted, access is still granted to the user via the readwrite-share.
     *
     * @example <caption>Code example</caption>
     * import { environmentSharesClient } from "@dynatrace-sdk/client-document";
     *
     * const data =
     *   await environmentSharesClient.deleteEnvironmentShare({
     *     id: "...",
     *   });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {ShareNotFound} Share not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteEnvironmentShare(config: {
        /** Environment-share id. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Claim another user's environment-share.
     *
     * **Required scope:** document:environment-shares:claim<br/><br/>Claim this environment-share, therefore gaining access to the share's document. From thereafter, the document will be accessible to you with the specific permissions defined by the share. You can then access the document as usual, via the same endpoints which you would use to access your own documents.
     *
     * Claiming your own shares is not possible. You can only claim shares of documents belonging to other users *of the same environment*.
     *
     * Once you have claimed access to a document, you can not revoke that access again.
     *
     * The document's owner can revoke your access by deleting the share. This will effectively revoke the access you have been granted by claiming this share.
     *
     * You can claim multiple shares of the same document, and each share will grant you different permissions.
     *
     * Claiming the same share multiple times does not have any effect.
     *
     * @returns {Promise<EnvironmentShareClaimResult>} You have successfully claimed this share and can now access the document with the granted permissions.
     *
     * @example <caption>Code example</caption>
     * import { environmentSharesClient } from "@dynatrace-sdk/client-document";
     *
     * const data =
     *   await environmentSharesClient.claimEnvironmentShare({
     *     id: "...",
     *   });
     *
     * @throws {ClaimingOwnedShareNotAllowed} A user can't claim one of their own shares.
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {ShareNotFound} Share not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    claimEnvironmentShare(config: {
        /** Share id. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<EnvironmentShareClaimResult>;
    /**
     * List the claimers of one of your environment-shares.
     *
     * **Required scope:** document:environment-shares:read<br/><br/>
     * Retrieve a share's claimers.
     *
     * Only the share's owner is permitted to do this.
     *
     * You can control the result's pagination via the `pageKey`, `page` and `pageSize` parameters.
     *
     * *Note, that at the moment we offer a naive pagination, and therefore interim document mutations and/or an
     * insufficient sort clause, if provided, can lead to result inconsistencies (such as duplicates, missing entries).*
     *
     * @returns {Promise<EnvironmentShareClaimerList>} A list of users who have claimed the environment-share.
     *
     * @example <caption>Code example</caption>
     * import { environmentSharesClient } from "@dynatrace-sdk/client-document";
     *
     * const data =
     *   await environmentSharesClient.getEnvironmentShareClaimers(
     *     { id: "..." },
     *   );
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {ShareNotFound} Share not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getEnvironmentShareClaimers(config: {
        /** Environment-share id. */ id: string;
        /**
         * The page key is used to query results from the next page.
         * You get a `nextPageKey` parameter in the return value of this method to use here.
         * If this parameter is omitted, the first page will be returned.
         */ pageKey?: string;
        /**
         * The page parameter is used to directly access a specific page.
         * The value of the page parameter, if specified, has to be a value greater than zero.
         * If the value of the page parameter exceeds the highest available page on the backend, an empty page is returned.
         */ page?: number;
        /**
         * The page size which defines the requested number of result entries. You can request a maximum of 1000 result entries.
         * If this parameter is omitted, the default value of 20 will be used.
         */ pageSize?: number;
        abortSignal?: AbortSignal;
    }): Promise<EnvironmentShareClaimerList>;
}
export declare const environmentSharesClient: EnvironmentSharesClient;
