import { AbortSignal, HttpClient } from '@dynatrace-sdk/http-client';
import { TrashDocument } from '../models/trash-document';
import { TrashDocumentList } from '../models/trash-document-list';
import { ApiClientOptions } from './api-client-options';
/**
 * Restore or irrevocably destroy your deleted documents.
 */
export declare class TrashClient {
    private httpClient;
    private shouldTransformDates;
    /**
     * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a TrashClient. Custom http client should implement {HttpClient} interface.
     * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
     * @example
     * const trashClientNodeJs = new TrashClient(yourCustomImplementation);
     */
    constructor(httpClientImplementation: HttpClient, options?: ApiClientOptions);
    /**
     * List your deleted documents.
     *
     * **Required scope:** document:trash.documents:read<br/><br/>Lists all documents, owned by you, which currently reside in the trash.
     *
     * Note that documents in the trash are irreversibly deleted after 30 days.
     *
     * *Note that at the moment we offer a naive pagination, and therefore interim document mutations and/or an
     *     insufficient sort clause, if provided, can lead to result inconsistencies (such as duplicates, missing entries).*
     *
     * @returns {Promise<TrashDocumentList>} A list of documents in the trash.
     *
     * @example <caption>Code example</caption>
     * import { trashClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await trashClient.listTrashedDocuments();
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    listTrashedDocuments(config?: {
        /**
         * The filter parameter, as explained [here](https://dt-url.net/platform-services-filtering).
         *
         * If this parameter is omitted, no filtering is applied and all your deleted documents will be returned.
         *
         * Filtering by string type parameters when using one of the operators `contains`, `starts-with` and `ends-with` is **case insensitive**.
         *
         * When using the equals operator or the not-equals operator, filtering is **case sensitive**.
         *
         * The following fields are legal filtering parameters - any other field names will result in a HTTP 400 response:
         *
         * `id`, `name`, `type`, `deletionInfo.deletedTime`, `deletionInfo.deletedBy`
         *
         * The following constraints apply:
         *
         * * Parameter names are **case-sensitive**.
         *
         * * Maximum nesting depth (via brackets) is 3.
         *
         * * Maximum length is 256 characters.
         */ filter?: string;
        /**
         * The page key is used to query results from the next page.
         * You get a `nextPageKey` parameter in the return value of this method to use here.
         * If this parameter is omitted, the first page will be returned.
         */ pageKey?: string;
        /**
         * The page parameter is used to directly access a specific page.
         * The value of the page parameter, if specified, has to be a value greater than zero.
         * If the value of the page parameter exceeds the highest available page on the backend, an empty page is returned.
         */ page?: number;
        /**
         * The page size which defines the requested number of result entries. You can request a maximum of 1000 result entries.
         * If this parameter is omitted, the default value of 20 will be used.
         */ pageSize?: number;
        abortSignal?: AbortSignal;
    }): Promise<TrashDocumentList>;
    /**
     * Inspect the deleted document.
     *
     * **Required scope:** document:trash.documents:read<br/><br/>Inspect the deleted document's metadata.
     * Only the document owner is permitted to do this.
     *
     * @returns {Promise<TrashDocument>} Metadata of a deleted document.
     *
     * @example <caption>Code example</caption>
     * import { trashClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await trashClient.inspectTrashedDocument({
     *   id: "...",
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {TrashedDocumentNotFound} Trashed document not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    inspectTrashedDocument(config: {
        /** System-generated id of a document. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<TrashDocument>;
    /**
     * Irreversibly destroy the document.
     *
     * **Required scope:** document:trash.documents:delete<br/><br/>This operation irreversibly destroys the document.
     * Only the document owner is permitted to do this.
     *
     * @example <caption>Code example</caption>
     * import { trashClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await trashClient.deleteTrashedDocument({
     *   id: "...",
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {TrashedDocumentNotFound} Trashed document not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteTrashedDocument(config: {
        /** System-generated id of a document. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Restore the deleted document.
     *
     * **Required scope:** document:trash.documents:restore<br/><br/>This operation restores the document from the trash.
     * All users who had access before the deletion regain their access to the document.
     * Only the document owner is permitted to do this.
     *
     * @example <caption>Code example</caption>
     * import { trashClient } from "@dynatrace-sdk/client-document";
     *
     * const data = await trashClient.restoreTrashedDocument({
     *   id: "...",
     * });
     *
     * @throws {Unauthorized} API token or tenant missing or corrupt.
     * @throws {Forbidden} Access forbidden. This usually happens because the user lacks the permission to access the specific endpoint, or because the target entity is not accessible to the user.
     * @throws {TrashedDocumentNotFound} Trashed document not found.
     * @throws {InternalServerError} There is a problem in the backend.
     * @throws {ServiceUnavailable} There is a temporary problem in the backend.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    restoreTrashedDocument(config: {
        /** System-generated id of a document. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<void>;
}
export declare const trashClient: TrashClient;
